@@ -218,10 +218,10 @@ class OstiumSDK:
                 - longOI: Total long open interest in notional value
                 - shortOI: Total short open interest in notional value
                 - maxOI: Maximum allowed open interest
-                - utilizationP: Utilization threshold percentage
+                
                 - makerFeeP: Maker fee percentage
                 - takerFeeP: Taker fee percentage
-                - usageFeeP: Usage fee percentage
+                
                 - maxLeverage: Maximum allowed leverage
                 - minLeverage: Minimum allowed leverage
                 - makerMaxLeverage: Maximum leverage for makers
@@ -261,7 +261,7 @@ class OstiumSDK:
                 'maxOI': Decimal(pair_details['maxOI']) / PRECISION_6,                
                 'makerFeeP': Decimal(pair_details['makerFeeP']) / PRECISION_6,
                 'takerFeeP': Decimal(pair_details['takerFeeP']) / PRECISION_6,
-                'usageFeeP': Decimal(pair_details['usageFeeP']) / PRECISION_6,
+                
                 'maxLeverage': Decimal(pair_details['group']['maxLeverage']) / PRECISION_2,
                 'minLeverage': Decimal(pair_details['group']['minLeverage']) / PRECISION_2,
                 'makerMaxLeverage': Decimal(pair_details['makerMaxLeverage']) / PRECISION_2,
